@@ -1,30 +1,33 @@
-# @(#)$Ident: Functions.pm 2013-12-31 18:44 pjf ;
+# @(#)$Ident: Functions.pm 2014-01-15 16:16 pjf ;
 
 package Class::Usul::Functions;
 
 use 5.010001;
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.35.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.37.%d', q$Rev: 1 $ =~ /\d+/gmx );
 use parent                  qw( Exporter::Tiny );
 
 use Class::Null;
 use Class::Usul::Constants;
-use Cwd                     qw( );
-use Data::Printer   alias => q(_data_dumper), colored => 1, indent => 3,
+use Cwd                        qw( );
+use Data::Printer      alias => q(_data_dumper), colored => 1, indent => 3,
     filters => { 'File::DataClass::IO' => sub { $_[ 0 ]->pathname }, };
-use Digest                  qw( );
-use Digest::MD5             qw( md5 );
-use English                 qw( -no_match_vars );
-use File::Basename          qw( basename dirname );
-use File::HomeDir           qw( );
-use File::Spec::Functions   qw( catdir catfile curdir tmpdir );
-use List::Util              qw( first );
-use Module::Runtime         qw( is_module_name require_module );
+use Digest                     qw( );
+use Digest::MD5                qw( md5 );
+use English                    qw( -no_match_vars );
+use File::Basename             qw( basename dirname );
+use File::DataClass::Functions qw( supported_extensions );
+use File::DataClass::IO        qw( );
+use File::HomeDir              qw( );
+use File::Spec::Functions      qw( catdir catfile curdir tmpdir );
+use List::Util                 qw( first );
+use Module::Runtime            qw( is_module_name require_module );
 use Path::Class::Dir;
-use Scalar::Util            qw( blessed openhandle );
+use Scalar::Util               qw( blessed openhandle );
 use Sys::Hostname;
-use Unexpected::Functions   qw( is_class_loaded Tainted Unspecified );
+use Unexpected::Functions      qw( is_class_loaded PathAlreadyExists
+                                   PathNotFound Tainted Unspecified );
 use User::pwent;
 
 our @EXPORT      = qw( is_member );
@@ -33,18 +36,18 @@ our @EXPORT_OK   = qw( abs_path app_prefix arg_list assert
                        base64_encode_ns bsonid bsonid_time bson64id
                        bson64id_time build class2appdir classdir
                        classfile create_token data_dumper distname
-                       downgrade elapsed emit emit_err emit_to
+                       elapsed emit emit_err emit_to
                        ensure_class_loaded env_prefix escape_TT
                        exception find_apphome find_source fold fqdn
                        fullname get_cfgfiles get_user hex2str
-                       home2appldir is_arrayref is_coderef
+                       home2appldir io is_arrayref is_coderef
                        is_hashref is_win32 loginid
                        logname merge_attributes my_prefix pad
                        prefix2class product split_on__ split_on_dash
-                       squeeze strip_leader sub_name sum thread_id
+                       squeeze strip_leader sub_name sum symlink thread_id
                        throw throw_on_error trim unescape_TT
                        untaint_cmdline untaint_identifier untaint_path
-                       untaint_string zip );
+                       untaint_string uuid zip );
 our %EXPORT_REFS =   ( assert => sub { ASSERT } );
 our %EXPORT_TAGS =   ( all => [ @EXPORT, @EXPORT_OK ], );
 
@@ -65,13 +68,12 @@ sub _exporter_fail {
 sub abs_path ($) {
    my $y = shift; (defined $y and length $y) or return $y;
 
-   (is_win32() or lc $OSNAME eq q(cygwin))
+   (is_win32() or lc $OSNAME eq 'cygwin')
       and not -e $y and return untaint_path( $y ); # Hate
 
    $y = Cwd::abs_path( untaint_path( $y ) );
 
    is_win32() and defined $y and $y =~ s{ / }{\\}gmx; # More hate
-
    return $y;
 }
 
@@ -80,15 +82,15 @@ sub app_prefix ($) {
 }
 
 sub arg_list (;@) {
-   return $_[ 0 ] && ref $_[ 0 ] eq q(HASH) ? { %{ $_[ 0 ] } }
-        : $_[ 0 ]                           ? { @_ }
-                                            : {};
+   return $_[ 0 ] && ref $_[ 0 ] eq 'HASH' ? { %{ $_[ 0 ] } }
+        : $_[ 0 ]                          ? { @_ }
+                                           : {};
 }
 
 sub assert_directory ($) {
    my $y = abs_path( $_[ 0 ] ); (defined $y and length $y) or return $y;
 
-   return -d $y ? $y : undef;
+   return -d "${y}" ? $y : undef;
 }
 
 sub base64_decode_ns ($) {
@@ -185,7 +187,7 @@ sub classdir ($) {
 }
 
 sub classfile ($) {
-   return catfile( split m{ :: }mx, $_[ 0 ].q(.pm) );
+   return catfile( split m{ :: }mx, $_[ 0 ].'.pm' );
 }
 
 sub create_token (;$) {
@@ -213,9 +215,9 @@ sub distname ($) {
    (my $y = $_[ 0 ] || q()) =~ s{ :: }{-}gmx; return $y;
 }
 
-sub downgrade (;$) {
-   my $x = shift || q(); my ($y) = $x =~ m{ (.*) }msx; return $y;
-}
+#sub downgrade (;$) {
+#   my $x = shift || q(); my ($y) = $x =~ m{ (.*) }msx; return $y;
+#}
 
 sub elapsed () {
    return time - $BASETIME;
@@ -247,7 +249,7 @@ sub emit_to ($;@) {
 sub ensure_class_loaded ($;$) {
    my ($class, $opts) = @_; $opts ||= {};
 
-   $class or throw( class => Unspecified, args => [ 'Class name' ] );
+   $class or throw( class => Unspecified, args => [ 'class name' ] );
    is_module_name( $class )
       or throw( error => 'String [_1] invalid classname', args => [ $class ] );
    not $opts->{ignore_loaded} and is_class_loaded( $class ) and return 1;
@@ -267,8 +269,8 @@ sub env_prefix ($) {
 
 sub escape_TT (;$$) {
    my $y  = defined $_[ 0 ] ? $_[ 0 ] : q();
-   my $fl = ($_[ 1 ] && $_[ 1 ]->[ 0 ]) || q(<);
-   my $fr = ($_[ 1 ] && $_[ 1 ]->[ 1 ]) || q(>);
+   my $fl = ($_[ 1 ] && $_[ 1 ]->[ 0 ]) || '<';
+   my $fr = ($_[ 1 ] && $_[ 1 ]->[ 1 ]) || '>';
 
    $y =~ s{ \[\% }{${fl}%}gmx; $y =~ s{ \%\] }{%${fr}}gmx;
 
@@ -295,15 +297,9 @@ sub find_apphome ($;$$) {
    $path = assert_directory $ENV{ "${env_pref}_HOME" } and return $path;
    # 1b.   Environment variable - for config file
    $path = _get_env_var_for_conf( $env_pref ) and return $path;
-   # 2a.   Users home directory - contains application directory
-   $path = catdir( $my_home, $appdir, qw( default lib ), $classdir );
-   $path = assert_directory $path and return $path;
-   # 2b.   Users home directory - dot directory containing application
-   $path = catdir( $my_home, ".${appdir}", qw( default lib ), $classdir );
-   $path = assert_directory $path and return $path;
-   # 2c.   Users home directory - dot file containing shell env variable
+   # 2a.   Users home directory - dot file containing shell env variable
    $path = _get_dot_file_var( $my_home, $app_pref, $classdir ) and return $path;
-   # 2d.   Users home directory - dot directory is apphome
+   # 2b.   Users home directory - dot directory is apphome
    $path = catdir( $my_home, ".${app_pref}" );
    $path = assert_directory $path and return $path;
    # 3.    Well known path containing shell env file
@@ -356,7 +352,7 @@ sub fullname () {
 sub get_cfgfiles ($;$$) {
    my ($appclass, $dirs, $extns) = @_;
 
-   $appclass // throw( class => Unspecified, args => [ 'Application class' ] );
+   $appclass // throw( class => Unspecified, args => [ 'application class' ] );
    is_arrayref( $dirs ) or $dirs = [ $dirs // curdir ];
 
    my $app_pref = app_prefix   $appclass;
@@ -366,7 +362,7 @@ sub get_cfgfiles ($;$$) {
    my @paths    = ();
 
    for my $dir (@{ $dirs }) {
-      for my $extn (@{ $extns || [ q() ] }) {
+      for my $extn (@{ $extns || [ supported_extensions() ] }) {
          for my $path (map { _catpath( $dir, $_ ) } "${app_pref}${extn}",
                        "${appdir}${extn}", "${app_pref}${suffix}${extn}",
                        "${appdir}${suffix}${extn}") {
@@ -398,16 +394,20 @@ sub home2appldir ($) {
    return $dir ne $dir->parent ? $dir->parent : undef;
 }
 
+sub io (;@) {
+   return File::DataClass::IO->new( @_ );
+}
+
 sub is_arrayref (;$) {
-   return $_[ 0 ] && ref $_[ 0 ] eq q(ARRAY) ? 1 : 0;
+   return $_[ 0 ] && ref $_[ 0 ] eq 'ARRAY' ? 1 : 0;
 }
 
 sub is_coderef (;$) {
-   return $_[ 0 ] && ref $_[ 0 ] eq q(CODE) ? 1 : 0;
+   return $_[ 0 ] && ref $_[ 0 ] eq 'CODE' ? 1 : 0;
 }
 
 sub is_hashref (;$) {
-   return $_[ 0 ] && ref $_[ 0 ] eq q(HASH) ? 1 : 0;
+   return $_[ 0 ] && ref $_[ 0 ] eq 'HASH' ? 1 : 0;
 }
 
 sub is_member (;@) {
@@ -462,7 +462,7 @@ sub pad ($$;$$) {
 }
 
 sub prefix2class (;$) {
-   return join q(::), map { ucfirst } split m{ - }mx, my_prefix( $_[ 0 ] );
+   return join '::', map { ucfirst } split m{ - }mx, my_prefix( $_[ 0 ] );
 }
 
 sub product (;@) {
@@ -488,13 +488,29 @@ sub strip_leader (;$) {
 sub sub_name (;$) {
    my $x = $_[ 0 ] || 0;
 
-   return (split m{ :: }mx, ((caller ++$x)[ 3 ]) || q(main))[ -1 ];
+   return (split m{ :: }mx, ((caller ++$x)[ 3 ]) || 'main')[ -1 ];
 }
 
 sub sum (;@) {
    return ((fold { $_[ 0 ] + $_[ 1 ] })->( 0 ))->( @_ );
 }
 
+sub symlink (;$$$) {
+   my ($from, $to, $base) = @_;
+
+   defined $base and not CORE::length $base and $base = File::Spec->rootdir;
+   $from or throw( class => Unspecified, args => [ 'path from' ] );
+   $from = io( $from )->absolute( $base );
+   $from->exists or throw( class => PathNotFound, args => [ "${from}" ] );
+   $to   or throw( class => Unspecified, args => [ 'path to' ] );
+   $to   = io( $to   )->absolute( $base ); $to->is_link and $to->unlink;
+   $to->exists  and throw( class => PathAlreadyExists, args => [ "${to}" ] );
+   CORE::symlink "${from}", "${to}"
+      or throw( error => 'Symlink from [_1] to [_2] failed: [_3]',
+                args  => [ "${from}", "${to}", $OS_ERROR ] );
+   return "Symlinked ${from} to ${to}";
+}
+
 sub thread_id {
    return exists $INC{ 'threads.pm' } ? threads->tid() : 0;
 }
@@ -515,8 +531,8 @@ sub trim (;$$) {
 
 sub unescape_TT (;$$) {
    my $y  = defined $_[ 0 ] ? $_[ 0 ] : q();
-   my $fl = ($_[ 1 ] && $_[ 1 ]->[ 0 ]) || q(<);
-   my $fr = ($_[ 1 ] && $_[ 1 ]->[ 1 ]) || q(>);
+   my $fl = ($_[ 1 ] && $_[ 1 ]->[ 0 ]) || '<';
+   my $fr = ($_[ 1 ] && $_[ 1 ]->[ 1 ]) || '>';
 
    $y =~ s{ ${fl}\% }{[%}gmx; $y =~ s{ \%${fr} }{%]}gmx;
 
@@ -548,13 +564,17 @@ sub untaint_string ($;$) {
    return $untainted;
 }
 
+sub uuid {
+   return io( $_[ 0 ] || UUID_PATH )->lock->chomp->getline;
+}
+
 sub zip (@) {
    my $p = @_ / 2; return @_[ map { $_, $_ + $p } 0 .. $p - 1 ];
 }
 
 # Private functions
 sub _base64_char_set () {
-   return [ 0 .. 9, q(A) .. q(Z), q(_), q(a) .. q(z), q(~), q(+) ];
+   return [ 0 .. 9, 'A' .. 'Z', '_', 'a' .. 'z', '~', '+' ];
 }
 
 sub _bsonid (;$) {
@@ -603,7 +623,7 @@ sub _find_conf_in_inc {
    my ($classdir, $file, $extns) = @_;
 
    for my $dir (map { catdir( abs_path( $_ ), $classdir ) } @INC) {
-      for my $extn (@{ $extns || [] }) {
+      for my $extn (@{ $extns || [ supported_extensions() ] }) {
          my $path = _catpath( $dir, $file.$extn );
 
          -f $path and return dirname( $path );
@@ -616,7 +636,7 @@ sub _find_conf_in_inc {
 sub _get_dot_file_var {
    my ($dir, $file, $classdir) = @_;
 
-   my $path; $path = _read_variable( catfile( $dir, ".${file}" ), 'APPLDIR' )
+   my $path; $path = _read_variable( $dir, ".${file}", 'APPLDIR' )
          and $path = catdir( $path, 'lib', $classdir );
 
    return $path = assert_directory $path ? $path : undef;
@@ -632,7 +652,7 @@ sub _get_env_var_for_conf {
 sub _get_known_file_var {
    my ($appname, $classdir) = @_; my $path; $appname || return;
 
-   $path = _read_variable( catfile( @{ DEFAULT_DIR() }, $appname ), 'APPLDIR' );
+   $path = _read_variable( DEFAULT_ENVDIR(), $appname, 'APPLDIR' );
    $path and $path = catdir( $path, 'lib', $classdir );
 
    return $path = assert_directory $path ? $path : undef;
@@ -659,17 +679,17 @@ sub _index64 () {
 }
 
 sub _read_variable {
-   my ($file, $variable) = @_; -f $file or return; $variable or return;
+   my ($dir, $file, $variable) = @_; my $path;
 
-   open my $fh, '<', $file or throw( "File ${file} cannot open: ${OS_ERROR}" );
+  ($dir and $file and $variable) or return;
+   is_arrayref( $dir ) and $dir = catdir( @{ $dir } );
+   $path = io( _catpath( $dir, $file ) )->chomp;
+  ($path->exists and $path->is_file) or return;
 
-   my $content = do { local $RS; <$fh> }; close $fh;
-
-   return first  { length }
-          map    { trim( (split q(=), $_)[ 1 ] ) }
-          grep   { m{ \A \s* $variable \s* [=] }mx }
-          map    { chomp }
-          split m{ [\n] }mx, $content;
+   return first   { length }
+          map     { trim( (split '=', $_)[ 1 ] ) }
+          grep    { m{ \A \s* $variable \s* [=] }mx }
+          reverse $path->getlines;
 }
 
 1;
@@ -684,7 +704,7 @@ CatalystX::Usul::Functions - Globally accessible functions
 
 =head1 Version
 
-This documents version v0.35.$Rev: 1 $
+This documents version v0.37.$Rev: 1 $
 
 =head1 Synopsis
 
@@ -949,6 +969,12 @@ Converts the pairs of hex digits into a string of characters
 
 Strips the trailing C<lib/my_package> from the supplied directory path
 
+=head2 io
+
+   $io_object_ref = io $path_to_file_or_directory;
+
+Returns a L<File::DataClass::IO> object reference
+
 =head2 is_arrayref
 
    $bool = is_arrayref $scalar_variable
@@ -969,7 +995,7 @@ Tests to see if the scalar variable is a hash ref
 
 =head2 is_member
 
-   $bool = is_member q(test_value), qw(a_value test_value b_value);
+   $bool = is_member 'test_value', qw( a_value test_value b_value );
 
 Tests to see if the first parameter is present in the list of
 remaining parameters
@@ -1071,6 +1097,14 @@ Returns the name of the method that calls it
 
 Adds the list of values
 
+=head2 symlink
+
+   $message = symlink $from, $to, $base;
+
+It creates a symlink. If either C<$from> or C<$to> is a relative path
+then C<$base> is prepended to make it absolute. Returns a message
+indicating success or throws an exception on failure
+
 =head2 thread_id
 
    $tid = thread_id;
@@ -1079,7 +1113,7 @@ Returns the id of this thread. Returns zero if threads are not loaded
 
 =head2 throw
 
-   throw error => q(error_key), args => [ q(error_arg) ];
+   throw error => 'error_key', args => [ 'error_arg' ];
 
 Expose L<Class::Usul::Exception/throw>. L<Class::Usul::Constants> has a
 class attribute I<Exception_Class> which can be set change the class
@@ -1103,7 +1137,7 @@ space and tab
 
 =head2 unescape_TT
 
-   $text = unescape_TT q(<% some_stash_key %>);
+   $text = unescape_TT '<% some_stash_key %>';
 
 Do the reverse of C<escape_TT>
 
@@ -1134,6 +1168,12 @@ matching regex from L<CatalystX::Usul::Constants>
 
 Returns an untainted string or throws
 
+=head2 uuid
+
+   $uuid = uuid( $optional_uuid_proc_filesystem_path );
+
+Return the contents of F</proc/sys/kernel/random/uuid>
+
 =head2 zip
 
    %hash = zip @list_of_keys, @list_of_values;
@@ -1171,6 +1211,8 @@ None
 The L</home2appldir> method is dependent on the installation path
 containing a B<lib>
 
+The L</uuid> method with only work on a OS with a F</proc> filesystem
+
 =head1 Bugs and Limitations
 
 There are no known bugs in this module.
